@@ -1,10 +1,9 @@
 use anchor_lang::solana_program::account_info::AccountInfo;
 use anchor_lang::solana_program::entrypoint::ProgramResult;
-use anchor_lang::solana_program::program_error::ProgramError;
 use anchor_lang::solana_program::pubkey::Pubkey;
-use anchor_lang::{Accounts, CpiContext};
+use anchor_lang::{context::CpiContext, Accounts};
 
-pub use spl_associated_token_account::ID;
+pub use spl_associated_token_account::{get_associated_token_address, ID};
 
 pub fn create<'info>(ctx: CpiContext<'_, '_, '_, 'info, Create<'info>>) -> ProgramResult {
     let ix = spl_associated_token_account::create_associated_token_account(
@@ -41,16 +40,6 @@ pub struct Create<'info> {
 #[derive(Clone)]
 pub struct AssociatedToken;
 
-impl anchor_lang::AccountDeserialize for AssociatedToken {
-    fn try_deserialize(buf: &mut &[u8]) -> Result<Self, ProgramError> {
-        AssociatedToken::try_deserialize_unchecked(buf)
-    }
-
-    fn try_deserialize_unchecked(_buf: &mut &[u8]) -> Result<Self, ProgramError> {
-        Ok(AssociatedToken)
-    }
-}
-
 impl anchor_lang::Id for AssociatedToken {
     fn id() -> Pubkey {
         ID
